{% extends "base.html" %}
{% load i18n %}
{% load bootstrap4 %}

{% block title %}
    {% trans "Reset password" %}
{% endblock %}

{% block content %}
    <h2>{% trans "Reset password" %}</h2>
    <form method="post">
        {% csrf_token %}
        {% bootstrap_form form %}
        {% trans "Reset password" as reset_message %}
        {% bootstrap_button reset_message "submit" %}
    </form>
{% endblock %}
