# Generated by Django 3.1.1 on 2020-09-21 19:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("event_management", "0008_event_mail_updates"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="event",
            options={
                "permissions": [("view_past_event", "Can view past events")],
                "verbose_name": "event",
                "verbose_name_plural": "events",
            },
        ),
        migrations.AlterField(
            model_name="shift",
            name="signup_configuration",
            field=models.JSONField(default=dict),
        ),
    ]
