# Generated by Django 3.1.1 on 2020-09-22 20:43

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Page",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("title", models.CharField(max_length=250)),
                ("content", models.TextField(blank=True)),
                ("slug", models.SlugField(max_length=250, unique=True)),
                ("show_in_footer", models.BooleanField(default=False)),
                ("publicly_visible", models.BooleanField(default=False)),
            ],
        ),
    ]
