{% extends "base.html" %}
{% load i18n %}

{% block title %}
    {% trans "Permission denied" %}
{% endblock %}

{% block content %}
    <div class="page-header"><h1>{% trans "Permission denied" %}</h1></div>
    <p>{% trans "You don't have the permission to view this page." %}</p>
{% endblock %}
