<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, user-scalable=false">
</head>
<body>
{% block content %}
    <p>{{ message_text }}</p>
{% endblock %}
</body>
</html>