{% extends "base.html" %}
{% load bootstrap4 %}
{% load i18n %}

{% block title %}
    {% if validlink %}
        {% trans "Set password" %}
    {% else %}
        {% trans "Invalid link" %}
    {% endif %}
{% endblock %}

{% block content %}
    {% if validlink %}
        <p>{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>
        <form method="post">
            {% csrf_token %}
            {% bootstrap_form form %}
            {% trans "Set password" as password_message %}
            {% bootstrap_button password_message "submit" %}
        </form>
    {% else %}
        <p>{% trans "The password reset link was invalid, possibly because it had already been used. Please request a new password reset." %}</p>
    {% endif %}
{% endblock %}
