{% extends "base.html" %}
{% load i18n %}
{% load bootstrap4 %}
{% load static %}

{% block title %}
    {% translate "Delete user" %}
{% endblock %}

{% block content %}
    <div class="page-header">
        <h1>{% translate "Delete user" %}</h1>
    </div>

    <form method="post">{% csrf_token %}
        <p>{% blocktranslate with name=userprofile.get_full_name %}
            Are you sure you want to delete the user {{ name }} ({{ userprofile }})?
        {% endblocktranslate %}</p>
        <a role="button" class="btn btn-secondary" href="{% url "user_management:userprofile_list" %}">{% translate "Back" %}</a>
        <button type="submit" class="btn btn-danger">{% translate "Delete" %}</button>
    </form>

{% endblock %}
