{% extends "base.html" %}
{% load i18n %}

{% block title %}
    {% trans "Bad request" %}
{% endblock %}

{% block content %}
    <div class="page-header"><h1>{% trans "Bad request" %}</h1></div>
    <p>{% trans "Your request contained invalid data, please try again. Please contact an administrator if the error recurs." %}</p>
{% endblock %}
