# Generated by Django 3.0.6 on 2020-08-29 21:48

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("event_management", "0004_auto_20200829_1535"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="event",
            options={"verbose_name": "event", "verbose_name_plural": "events"},
        ),
        migrations.AlterModelOptions(
            name="eventtype",
            options={"verbose_name": "event type", "verbose_name_plural": "event types"},
        ),
        migrations.AlterModelOptions(
            name="shift",
            options={"verbose_name": "shift", "verbose_name_plural": "shifts"},
        ),
        migrations.AlterField(
            model_name="abstractparticipation",
            name="shift",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="event_management.Shift",
                verbose_name="shift",
            ),
        ),
        migrations.AlterField(
            model_name="abstractparticipation",
            name="state",
            field=models.IntegerField(
                choices=[
                    (0, "requested"),
                    (1, "confirmed"),
                    (2, "declined by user"),
                    (3, "rejected by responsible"),
                ],
                default=0,
                verbose_name="state",
            ),
        ),
        migrations.AlterField(
            model_name="event",
            name="description",
            field=models.TextField(blank=True, null=True, verbose_name="description"),
        ),
        migrations.AlterField(
            model_name="event",
            name="location",
            field=models.CharField(max_length=254, verbose_name="location"),
        ),
        migrations.AlterField(
            model_name="event",
            name="title",
            field=models.CharField(max_length=254, verbose_name="title"),
        ),
        migrations.AlterField(
            model_name="event",
            name="type",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="event_management.EventType",
                verbose_name="event type",
            ),
        ),
        migrations.AlterField(
            model_name="eventtype",
            name="can_grant_qualification",
            field=models.BooleanField(verbose_name="can grant qualification"),
        ),
        migrations.AlterField(
            model_name="eventtype",
            name="title",
            field=models.CharField(max_length=254, verbose_name="title"),
        ),
        migrations.AlterField(
            model_name="shift",
            name="end_time",
            field=models.DateTimeField(verbose_name="end time"),
        ),
        migrations.AlterField(
            model_name="shift",
            name="event",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="shifts",
                to="event_management.Event",
                verbose_name="shifts",
            ),
        ),
        migrations.AlterField(
            model_name="shift",
            name="meeting_time",
            field=models.DateTimeField(verbose_name="meeting time"),
        ),
        migrations.AlterField(
            model_name="shift",
            name="signup_method_slug",
            field=models.SlugField(verbose_name="signup method"),
        ),
        migrations.AlterField(
            model_name="shift",
            name="start_time",
            field=models.DateTimeField(verbose_name="start time"),
        ),
    ]
