{% extends "base.html" %}
{% load i18n %}
{% load bootstrap4 %}

{% block title %}
    {% trans "Login" %}
{% endblock %}

{% block content %}
    {% trans "Login" as login_message %}
    <h2>{{ login_message }}</h2>
    <form method="post">
        {% csrf_token %}
        {% bootstrap_form form %}
        {% bootstrap_button login_message "submit" %}
        <a class="float-right" href="{% url "password_reset" %}">{% translate "Forgot your password?" %}</a>
    </form>
{% endblock %}