# Generated by Django 3.0.6 on 2020-08-25 11:51

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("event_management", "0002_event_active"),
    ]

    operations = [
        migrations.AlterField(
            model_name="shift",
            name="event",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="shifts",
                to="event_management.Event",
            ),
        ),
        migrations.AlterField(
            model_name="shift",
            name="signup_method_slug",
            field=models.SlugField(verbose_name="Signup method"),
        ),
    ]
