# Generated by Django 3.0.6 on 2020-08-27 14:04

import secrets

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("user_management", "0002_initial_permissions"),
    ]

    operations = [
        migrations.AddField(
            model_name="userprofile",
            name="calendar_token",
            field=models.CharField(default=secrets.token_urlsafe, max_length=254),
        ),
    ]
