{% extends "base.html" %}
{% load i18n %}
{% load rich_text %}

{% block title %}
    {% translate "Disposition" %}
{% endblock %}

{% block content %}
    <div class="page-header">
        <h1>{{ page.title }}</h1>
    </div>

    <div>
        {{ page.content|rich_text }}
    </div>

{% endblock %}
