# Generated by Django 3.0.6 on 2020-08-29 23:16

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("event_management", "0005_auto_20200829_2348"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="abstractparticipation",
            options={"base_manager_name": "objects"},
        ),
        migrations.AlterModelOptions(
            name="localparticipation",
            options={"base_manager_name": "objects"},
        ),
        migrations.AddField(
            model_name="abstractparticipation",
            name="polymorphic_ctype",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="polymorphic_event_management.abstractparticipation_set+",
                to="contenttypes.ContentType",
            ),
        ),
    ]
