{% extends "base.html" %}
{% load i18n %}
{% load bootstrap4 %}

{% block title %}
    {% trans "Password changed successfully" %}
{% endblock %}

{% block content %}
    <h2>{% trans "Password changed successfully" %}</h2>
    <a class="btn btn-primary" href="{% url "event_management:index" %}">{% trans "Back to home page" %}</a>
{% endblock %}