{% extends "base.html" %}
{% load bootstrap4 %}
{% load i18n %}

{% block title %}
    {% trans "Password set successfully" %}
{% endblock %}

{% block content %}
    <h2>{% trans "Password set successfully" %}</h2>
    <p>{% trans "Your password has been set. You may go ahead and log in now." %}</p>
    <a class="btn btn-primary" href="{% url "login" %}">{% trans "Login" %}</a>
{% endblock %}