{% extends "base.html" %}
{% load i18n %}

{% block title %}
    {% trans "Home" %}
{% endblock %}

{% block content %}
<h1 class="page-header">
    {% trans "Welcome to ephios!" %}
</h1>
{% endblock %}