# Generated by Django 3.0.6 on 2020-08-24 11:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("event_management", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="event",
            name="active",
            field=models.BooleanField(default=False),
        ),
    ]
