{% extends "base.html" %}
{% load i18n %}
{% load bootstrap4%}

{% block title %}
    {% trans "Logged out" %}
{% endblock %}

{% block content %}
    {% trans "Logged out successfully." %} <br>
    {% url "login" as login_url %}
    {% trans "Back to login" as back_message %}
    {% bootstrap_button content=back_message href=login_url %}
{% endblock %}