# Generated by Django 3.0.6 on 2020-08-29 13:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("event_management", "0003_auto_20200825_1351"),
    ]

    operations = [
        migrations.AlterField(
            model_name="abstractparticipation",
            name="state",
            field=models.IntegerField(
                choices=[
                    (0, "requested"),
                    (1, "confirmed"),
                    (2, "declined by user"),
                    (3, "rejected by responsible"),
                ],
                default=0,
            ),
        ),
    ]
