{% extends "base.html" %}
{% load i18n %}
{% load bootstrap4 %}

{% block title %}
    {% trans "Password reset successfully" %}
{% endblock %}

{% block content %}
    <h2>{% trans "Password reset successfully" %}</h2>
    <p>{% trans "Please check your mailbox for further instructions." %}</p>
    <a class="btn btn-primary" href="{% url "login" %}">{% trans "Back to login" %}</a>
{% endblock %}